==> haskell-th-abstraction-0.2.4.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-abstraction.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-abstraction
version: 0.2.4.0
id: th-abstraction-0.2.4.0-BAl9T2IHxjI7WRSl2bnPZg
key: th-abstraction-0.2.4.0-BAl9T2IHxjI7WRSl2bnPZg
license: ISC
copyright: 2017 Eric Mertens
maintainer: emertens@gmail.com
homepage: https://github.com/glguy/th-abstraction
synopsis: Nicer interface for reified information about data types
description:
    This package normalizes variations in the interface for
    inspecting datatype information via Template Haskell
    so that packages and support a single, easier to use
    informational datatype while supporting many versions
    of Template Haskell.
category: Development
author: Eric Mertens
exposed: True
exposed-modules:
    Language.Haskell.TH.Datatype
hidden-modules: Language.Haskell.TH.Datatype.Internal
abi: 96ab4cc93a3c2377e0721c483fd8db78
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/th-abstraction-0.2.4.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/th-abstraction-0.2.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/th-abstraction-0.2.4.0
hs-libraries: HSth-abstraction-0.2.4.0-BAl9T2IHxjI7WRSl2bnPZg
depends:
    base-4.9.1.0 containers-0.5.7.1 ghc-prim-0.5.0.0
    template-haskell-2.11.1.0
haddock-interfaces: /usr/share/doc/haskell-th-abstraction/html/th-abstraction.haddock
haddock-html: /usr/share/doc/haskell-th-abstraction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-th-abstraction-0.2.5.0-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-th-abstraction.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: th-abstraction
version: 0.2.5.0
id: th-abstraction-0.2.5.0-IQJC3onXzKuCarhyL6pEOQ
key: th-abstraction-0.2.5.0-IQJC3onXzKuCarhyL6pEOQ
license: ISC
copyright: 2017 Eric Mertens
maintainer: emertens@gmail.com
homepage: https://github.com/glguy/th-abstraction
synopsis: Nicer interface for reified information about data types
description:
    This package normalizes variations in the interface for
    inspecting datatype information via Template Haskell
    so that packages and support a single, easier to use
    informational datatype while supporting many versions
    of Template Haskell.
category: Development
author: Eric Mertens
exposed: True
exposed-modules:
    Language.Haskell.TH.Datatype
hidden-modules: Language.Haskell.TH.Datatype.Internal
abi: a3c57dfb625e2c206f68895213ef8a16
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/th-abstraction-0.2.5.0
library-dirs: /usr/lib/ghc-8.0.2/site-local/th-abstraction-0.2.5.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.0.2/th-abstraction-0.2.5.0
hs-libraries: HSth-abstraction-0.2.5.0-IQJC3onXzKuCarhyL6pEOQ
depends:
    base-4.9.1.0 containers-0.5.7.1 ghc-prim-0.5.0.0
    template-haskell-2.11.1.0
haddock-interfaces: /usr/share/doc/haskell-th-abstraction/html/th-abstraction.haddock
haddock-html: /usr/share/doc/haskell-th-abstraction/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
